@@ -18,7 +18,8 @@ except:
 		import deltaRice.h5
 		__nabCompressionAvail = True
 	except:
-		print('deltaRice / NabCompression libaries unavailable')
+		__nabCompressionAvail = False
+
 import h5py
 import dask
 import dask.array as da
@@ -581,7 +582,7 @@ class waveformFile:
 					print('trap method takes 3-6 inputs: rise time, top length, decay rate, (threshold percent, mean, shift)')
 					return None
 				else:
-					eners, times = bf.applyTrapFilter(self.waves(prep=False), *params, pretrigger=pretrig, batchsize=batchsize, useGPU = useGPU, shift = shift, mean = mean, hdf5ChunkSize = self.hdf5ChunkSize, rechunk=rechunk, useFFTW = useFFTW)
+					eners, times = bf.applyTrapFilter(self.waves(prep=False), *params, pretrigger=pretrig, batchsize=batchsize, useGPU = useGPU, mean = mean, hdf5ChunkSize = self.hdf5ChunkSize, rechunk=rechunk, useFFTW = useFFTW)
 					headers = None
 					if self.headers() is not None:
 						headers = self.headers().copy()
